DiscriminatorOpenApi class

Annotations
  • @SpecsSerializable.new()

Constructors

DiscriminatorOpenApi({required String propertyName, required Map<String, String> mapping})
const
DiscriminatorOpenApi.fromJson(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
mapping → Map<String, String>
final
propertyName → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited