GroupMediaOpenApi class

Annotations
  • @SpecsSerializable.new()

Constructors

GroupMediaOpenApi({Map? originalJson, MediaOpenApi? textPlain, MediaOpenApi? json, MediaOpenApi? urlEncoded, MediaOpenApi? octetStream, MediaOpenApi? formData, MediaOpenApi? image, MediaOpenApi? any})
const
GroupMediaOpenApi.fromJson(Map map)
factory

Properties

any → MediaOpenApi?
final
formData → MediaOpenApi?
final
hashCode → int
The hash code for this object.
no setterinherited
image → MediaOpenApi?
final
json → MediaOpenApi?
final
jsonOrAny → MediaOpenApi?
no setter
octetStream → MediaOpenApi?
final
originalJson → Map?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → MediaOpenApi?
no setter
textPlain → MediaOpenApi?
final
urlEncoded → MediaOpenApi?
final

Methods

ensureIsNotNull<T>(String fieldName, T? value) → T
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited