InfoOpenApi class

Version: 3.0.3

Annotations
  • @SpecsSerializable.new()

Constructors

InfoOpenApi({required String title, String? description, String? termsOfService, required String version})
const
InfoOpenApi.fromJson(Map map)
factory

Properties

description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
termsOfService → String?
final
title → String
final
version → String
final

Methods

copyWith({String? title, String? description, String? termsOfService, String? version}) → InfoOpenApi
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited