ItemPathOpenApi class

Annotations
  • @SpecsSerializable.new()

Constructors

ItemPathOpenApi({String? summary, String? description, OperationOpenApi? get, OperationOpenApi? put, OperationOpenApi? post, OperationOpenApi? delete, OperationOpenApi? head, OperationOpenApi? patch})
const
ItemPathOpenApi.from({String? summary, String? description, required Map<String, OperationOpenApi> operations})
factory
ItemPathOpenApi.fromJson(Map map)
factory

Properties

delete → OperationOpenApi?
final
description → String?
final
get → OperationOpenApi?
final
hashCode → int
The hash code for this object.
no setterinherited
final
operations → Map<String, OperationOpenApi>
no setter
patch → OperationOpenApi?
final
post → OperationOpenApi?
final
put → OperationOpenApi?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
summary → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited