MediaOpenApi class

Annotations
  • @SpecsSerializable.new()

Constructors

MediaOpenApi({String? example, Map<String, dynamic> examples = const {}, required SchemaOrRef schema})
const
MediaOpenApi.fromJson(Map map)
factory

Properties

example → String?
final
examples → Map<String, dynamic>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → SchemaOrRef
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited