OAuthFlowOpenApi class

Version: 3.0.3

Annotations
  • @SpecsSerializable.new()

Constructors

OAuthFlowOpenApi({String? authorizationUrl, required String tokenUrl, String? refreshUrl, required Map<String, String> scopes})
const
OAuthFlowOpenApi.fromJson(Map map)
factory

Properties

authorizationUrl → String?
final
hashCode → int
The hash code for this object.
no setterinherited
refreshUrl → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes → Map<String, String>
final
tokenUrl → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited