OpenApi class

Documentation: https://swagger.io/specification

Version: 3.0.3

Annotations
  • @SpecsSerializable.new()

Constructors

OpenApi({required String openapi, required InfoOpenApi info, List<ServerOpenApi> servers = const [], required Map<String, ItemPathOpenApi> paths, ComponentsOpenApi components = const ComponentsOpenApi(), List<TagOpenApi> tags = const []})
const
OpenApi.fromJson(Map map)
factory

Properties

components → ComponentsOpenApi
final
hashCode → int
The hash code for this object.
no setterinherited
info → InfoOpenApi
final
openapi → String
final
paths → Map<String, ItemPathOpenApi>
Endpoint path
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
servers → List<ServerOpenApi>
final
tags → List<TagOpenApi>
final

Methods

copyWith({InfoOpenApi? info, List<ServerOpenApi>? servers}) → OpenApi
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited