ParameterInOpenApi enum

Inheritance
Available extensions
Annotations
  • @JsonEnum.new()

Values

path → const ParameterInOpenApi
query → const ParameterInOpenApi

Properties

Available on ParameterInOpenApi, provided by the ParameterInOpenApiExtensions extension

no setter
hashCode → int
The hash code for this object.
no setterinherited

Available on ParameterInOpenApi, provided by the ParameterInOpenApiExtensions extension

no setter
index → int
A numeric identifier for the enumerated value.
no setterinherited
isQuery → bool

Available on ParameterInOpenApi, provided by the ParameterInOpenApiExt extension

no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
path → bool

Available on ParameterInOpenApi, provided by the ParameterInOpenApiExtensions extension

no setter
query → bool

Available on ParameterInOpenApi, provided by the ParameterInOpenApiExtensions extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String

Available on ParameterInOpenApi, provided by the ParameterInOpenApiExt extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<ParameterInOpenApi>
A constant List of the values in this enum, in order of their declaration.