ParameterOpenApi class

Annotations
  • @SpecsSerializable.new()

Constructors

ParameterOpenApi({String? description, Object? example, required String name, required ParameterInOpenApi in$, bool required = false, bool deprecated = false, String? style, bool? explode, required SchemaOrRef? schema, Map<String, dynamic> examples = const {}})
const
ParameterOpenApi.fromJson(Map map)
factory

Properties

deprecated → bool
final
description → String?
final
example → Object?
final
examples → Map<String, dynamic>
final
explode → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
in$ → ParameterInOpenApi
final
name → String
final
required → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → SchemaOrRef?
final
style → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited