RequestBodyOpenApi class

Annotations
  • @SpecsSerializable.new()

Constructors

RequestBodyOpenApi({String? description, bool required = false, required GroupMediaOpenApi content})
const
RequestBodyOpenApi.fromJson(Map map)
factory

Properties

content → GroupMediaOpenApi
final
description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
required → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited