SchemaOpenApi class

Implemented types
Available extensions
Annotations
  • @SpecsSerializable.new()

Constructors

SchemaOpenApi({Map? originalJson, String? name, String? title, String? description, Object? example, TypeOpenApi? type, FormatOpenApi? format, List<Object>? enum$, SchemaOrRef? items, Map<String, SchemaOrRef>? properties, SchemaOrRef? additionalProperties, SchemaOrRef? propertyNames, List<SchemaOrRef>? allOf, List<SchemaOrRef>? oneOf, DiscriminatorOpenApi? discriminator, List<String>? required, bool nullable = false, Object? default$, Object? $original, bool? uniqueItems})
const
SchemaOpenApi.fromJson(Map map)
factory

Properties

$original → Object?
final
additionalProperties → SchemaOrRef?
final
allOf → List<SchemaOrRef>?
final
default$ → Object?
final
description → String?
final
discriminator → DiscriminatorOpenApi?
final
enum$ → List<Object>?
With TypeOpenApi.integer | TypeOpenApi.string
final
example → Object?
final
format → FormatOpenApi?
final
hashCode → int
The hash code for this object.
no setterinherited
isClass → bool

Available on SchemaOpenApi, provided by the SchemaOpenApiX extension

no setter
isEnum → bool

Available on SchemaOpenApi, provided by the SchemaOpenApiX extension

no setter
items → SchemaOrRef?
Must be present if the type is TypeOpenApi.array
final
name → String?
final
nullable → bool
final
oneOf → List<SchemaOrRef>?
final
originalJson → Map?
finalinherited
properties → Map<String, SchemaOrRef>?
With TypeOpenApi.object
final
propertyNames → SchemaOrRef?
With TypeOpenApi.object. It define a Map<String, *>
final
required → List<String>?
With TypeOpenApi.object
final
requireName → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
final
type → TypeOpenApi?
final
uniqueItems → bool?
Json Properties
final

Methods

canNull(String name, SchemaOpenApi schema) → bool

Available on SchemaOpenApi, provided by the SchemaOpenApiX extension

A schema contains this property A property name
ensureIsNotNull<T>(String fieldName, T? value) → T
inherited
isRequired(String name) → bool

Available on SchemaOpenApi, provided by the SchemaOpenApiX extension

A schema contains this property A property name
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(ComponentsOpenApi components) → SchemaOpenApi
override
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited