SchemaRef class

Inheritance

Constructors

SchemaRef(String ref)
factory
SchemaRef.from(String identifier)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ref String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(ComponentsOpenApi components) SchemaOpenApi
override
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited